pub enum MessageTransmitterEvents {
Show 13 variants
AttesterDisabled(AttesterDisabled),
AttesterEnabled(AttesterEnabled),
AttesterManagerUpdated(AttesterManagerUpdated),
MaxMessageBodySizeUpdated(MaxMessageBodySizeUpdated),
MessageReceived(MessageReceived),
MessageSent(MessageSent),
OwnershipTransferStarted(OwnershipTransferStarted),
OwnershipTransferred(OwnershipTransferred),
Pause(Pause),
PauserChanged(PauserChanged),
RescuerChanged(RescuerChanged),
SignatureThresholdUpdated(SignatureThresholdUpdated),
Unpause(Unpause),
}Expand description
Container for all the MessageTransmitter events.
Variants
AttesterDisabled(AttesterDisabled)
AttesterEnabled(AttesterEnabled)
AttesterManagerUpdated(AttesterManagerUpdated)
MaxMessageBodySizeUpdated(MaxMessageBodySizeUpdated)
MessageReceived(MessageReceived)
MessageSent(MessageSent)
OwnershipTransferStarted(OwnershipTransferStarted)
OwnershipTransferred(OwnershipTransferred)
Pause(Pause)
PauserChanged(PauserChanged)
RescuerChanged(RescuerChanged)
SignatureThresholdUpdated(SignatureThresholdUpdated)
Unpause(Unpause)
Implementations
Sourceimpl MessageTransmitterEvents
impl MessageTransmitterEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl MessageTransmitterEvents
impl MessageTransmitterEvents
Sourcepub fn attester_disabled(attester: Address) -> Self
pub fn attester_disabled(attester: Address) -> Self
Creates a AttesterDisabled event.
event AttesterDisabled(address)Sourcepub fn attester_enabled(attester: Address) -> Self
pub fn attester_enabled(attester: Address) -> Self
Creates a AttesterEnabled event.
event AttesterEnabled(address)Sourcepub fn attester_manager_updated(
previous_attester_manager: Address,
new_attester_manager: Address,
) -> Self
pub fn attester_manager_updated( previous_attester_manager: Address, new_attester_manager: Address, ) -> Self
Creates a AttesterManagerUpdated event.
event AttesterManagerUpdated(address,address)Sourcepub fn max_message_body_size_updated(new_max_message_body_size: U256) -> Self
pub fn max_message_body_size_updated(new_max_message_body_size: U256) -> Self
Creates a MaxMessageBodySizeUpdated event.
event MaxMessageBodySizeUpdated(uint256)Sourcepub fn message_received(
caller: Address,
source_domain: u32,
nonce: u64,
sender: FixedBytes<32>,
message_body: Bytes,
) -> Self
pub fn message_received( caller: Address, source_domain: u32, nonce: u64, sender: FixedBytes<32>, message_body: Bytes, ) -> Self
Creates a MessageReceived event.
event MessageReceived(address,uint32,uint64,bytes32,bytes)Sourcepub fn message_sent(message: Bytes) -> Self
pub fn message_sent(message: Bytes) -> Self
Creates a MessageSent event.
event MessageSent(bytes)Sourcepub fn ownership_transfer_started(
previous_owner: Address,
new_owner: Address,
) -> Self
pub fn ownership_transfer_started( previous_owner: Address, new_owner: Address, ) -> Self
Creates a OwnershipTransferStarted event.
event OwnershipTransferStarted(address,address)Sourcepub fn ownership_transferred(
previous_owner: Address,
new_owner: Address,
) -> Self
pub fn ownership_transferred( previous_owner: Address, new_owner: Address, ) -> Self
Creates a OwnershipTransferred event.
event OwnershipTransferred(address,address)Sourcepub fn pauser_changed(new_address: Address) -> Self
pub fn pauser_changed(new_address: Address) -> Self
Creates a PauserChanged event.
event PauserChanged(address)Sourcepub fn rescuer_changed(new_rescuer: Address) -> Self
pub fn rescuer_changed(new_rescuer: Address) -> Self
Creates a RescuerChanged event.
event RescuerChanged(address)Sourcepub fn signature_threshold_updated(
old_signature_threshold: U256,
new_signature_threshold: U256,
) -> Self
pub fn signature_threshold_updated( old_signature_threshold: U256, new_signature_threshold: U256, ) -> Self
Creates a SignatureThresholdUpdated event.
event SignatureThresholdUpdated(uint256,uint256)Trait Implementations
Sourceimpl Clone for MessageTransmitterEvents
impl Clone for MessageTransmitterEvents
Sourcefn clone(&self) -> MessageTransmitterEvents
fn clone(&self) -> MessageTransmitterEvents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl IntoLogData for MessageTransmitterEvents
impl IntoLogData for MessageTransmitterEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEventInterface for MessageTransmitterEvents
impl SolEventInterface for MessageTransmitterEvents