MessageTransmitterInstance

Struct MessageTransmitterInstance 

pub struct MessageTransmitterInstance<P, N = Ethereum> { /* private fields */ }
A MessageTransmitter instance.

Contains type-safe methods for interacting with an on-chain instance of the MessageTransmitter contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Implementations

Source

impl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>

Instantiation and getters/setters.

pub const fn new(address: Address, __provider: P) -> Self

Creates a new wrapper around an on-chain MessageTransmitter contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> Self

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.

Source

impl<P: Clone, N> MessageTransmitterInstance<&P, N>

pub fn with_cloned_provider(self) -> MessageTransmitterInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.

Source

impl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>

Function calls.

pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>

Creates a new call builder for the [acceptOwnership] function.

pub fn attesterManager(&self) -> SolCallBuilder<&P, attesterManagerCall, N>

Creates a new call builder for the [attesterManager] function.

pub fn disableAttester( &self, attester: Address, ) -> SolCallBuilder<&P, disableAttesterCall, N>

Creates a new call builder for the [disableAttester] function.

pub fn enableAttester( &self, newAttester: Address, ) -> SolCallBuilder<&P, enableAttesterCall, N>

Creates a new call builder for the [enableAttester] function.

pub fn getEnabledAttester( &self, index: U256, ) -> SolCallBuilder<&P, getEnabledAttesterCall, N>

Creates a new call builder for the [getEnabledAttester] function.

pub fn getNumEnabledAttesters( &self, ) -> SolCallBuilder<&P, getNumEnabledAttestersCall, N>

Creates a new call builder for the [getNumEnabledAttesters] function.

pub fn isEnabledAttester( &self, attester: Address, ) -> SolCallBuilder<&P, isEnabledAttesterCall, N>

Creates a new call builder for the [isEnabledAttester] function.

pub fn localDomain(&self) -> SolCallBuilder<&P, localDomainCall, N>

Creates a new call builder for the [localDomain] function.

pub fn maxMessageBodySize( &self, ) -> SolCallBuilder<&P, maxMessageBodySizeCall, N>

Creates a new call builder for the [maxMessageBodySize] function.

pub fn nextAvailableNonce( &self, ) -> SolCallBuilder<&P, nextAvailableNonceCall, N>

Creates a new call builder for the [nextAvailableNonce] function.

pub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>

Creates a new call builder for the [owner] function.

pub fn pause(&self) -> SolCallBuilder<&P, pauseCall, N>

Creates a new call builder for the [pause] function.

pub fn paused(&self) -> SolCallBuilder<&P, pausedCall, N>

Creates a new call builder for the [paused] function.

pub fn pauser(&self) -> SolCallBuilder<&P, pauserCall, N>

Creates a new call builder for the [pauser] function.

pub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>

Creates a new call builder for the [pendingOwner] function.

pub fn receiveMessage( &self, message: Bytes, attestation: Bytes, ) -> SolCallBuilder<&P, receiveMessageCall, N>

Creates a new call builder for the [receiveMessage] function.

pub fn replaceMessage( &self, originalMessage: Bytes, originalAttestation: Bytes, newMessageBody: Bytes, newDestinationCaller: FixedBytes<32>, ) -> SolCallBuilder<&P, replaceMessageCall, N>

Creates a new call builder for the [replaceMessage] function.

pub fn rescueERC20( &self, tokenContract: Address, to: Address, amount: U256, ) -> SolCallBuilder<&P, rescueERC20Call, N>

Creates a new call builder for the [rescueERC20] function.

pub fn rescuer(&self) -> SolCallBuilder<&P, rescuerCall, N>

Creates a new call builder for the [rescuer] function.

pub fn sendMessage( &self, destinationDomain: u32, recipient: FixedBytes<32>, messageBody: Bytes, ) -> SolCallBuilder<&P, sendMessageCall, N>

Creates a new call builder for the [sendMessage] function.

pub fn sendMessageWithCaller( &self, destinationDomain: u32, recipient: FixedBytes<32>, destinationCaller: FixedBytes<32>, messageBody: Bytes, ) -> SolCallBuilder<&P, sendMessageWithCallerCall, N>

Creates a new call builder for the [sendMessageWithCaller] function.

pub fn setMaxMessageBodySize( &self, newMaxMessageBodySize: U256, ) -> SolCallBuilder<&P, setMaxMessageBodySizeCall, N>

Creates a new call builder for the [setMaxMessageBodySize] function.

pub fn setSignatureThreshold( &self, newSignatureThreshold: U256, ) -> SolCallBuilder<&P, setSignatureThresholdCall, N>

Creates a new call builder for the [setSignatureThreshold] function.

pub fn signatureThreshold( &self, ) -> SolCallBuilder<&P, signatureThresholdCall, N>

Creates a new call builder for the [signatureThreshold] function.

pub fn transferOwnership( &self, newOwner: Address, ) -> SolCallBuilder<&P, transferOwnershipCall, N>

Creates a new call builder for the [transferOwnership] function.

pub fn unpause(&self) -> SolCallBuilder<&P, unpauseCall, N>

Creates a new call builder for the [unpause] function.

pub fn updateAttesterManager( &self, newAttesterManager: Address, ) -> SolCallBuilder<&P, updateAttesterManagerCall, N>

Creates a new call builder for the [updateAttesterManager] function.

pub fn updatePauser( &self, _newPauser: Address, ) -> SolCallBuilder<&P, updatePauserCall, N>

Creates a new call builder for the [updatePauser] function.

pub fn updateRescuer( &self, newRescuer: Address, ) -> SolCallBuilder<&P, updateRescuerCall, N>

Creates a new call builder for the [updateRescuer] function.

pub fn usedNonces( &self, _0: FixedBytes<32>, ) -> SolCallBuilder<&P, usedNoncesCall, N>

Creates a new call builder for the [usedNonces] function.

pub fn version(&self) -> SolCallBuilder<&P, versionCall, N>

Creates a new call builder for the [version] function.

Source

impl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>

Event filters.

pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn AttesterDisabled_filter(&self) -> Event<&P, AttesterDisabled, N>

Creates a new event filter for the AttesterDisabled event.

pub fn AttesterEnabled_filter(&self) -> Event<&P, AttesterEnabled, N>

Creates a new event filter for the AttesterEnabled event.

pub fn AttesterManagerUpdated_filter( &self, ) -> Event<&P, AttesterManagerUpdated, N>

Creates a new event filter for the AttesterManagerUpdated event.

pub fn MaxMessageBodySizeUpdated_filter( &self, ) -> Event<&P, MaxMessageBodySizeUpdated, N>

Creates a new event filter for the MaxMessageBodySizeUpdated event.

pub fn MessageReceived_filter(&self) -> Event<&P, MessageReceived, N>

Creates a new event filter for the MessageReceived event.

pub fn MessageSent_filter(&self) -> Event<&P, MessageSent, N>

Creates a new event filter for the MessageSent event.

pub fn OwnershipTransferStarted_filter( &self, ) -> Event<&P, OwnershipTransferStarted, N>

Creates a new event filter for the OwnershipTransferStarted event.

pub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>

Creates a new event filter for the OwnershipTransferred event.

pub fn Pause_filter(&self) -> Event<&P, Pause, N>

Creates a new event filter for the Pause event.

pub fn PauserChanged_filter(&self) -> Event<&P, PauserChanged, N>

Creates a new event filter for the PauserChanged event.

pub fn RescuerChanged_filter(&self) -> Event<&P, RescuerChanged, N>

Creates a new event filter for the RescuerChanged event.

pub fn SignatureThresholdUpdated_filter( &self, ) -> Event<&P, SignatureThresholdUpdated, N>

Creates a new event filter for the SignatureThresholdUpdated event.

pub fn Unpause_filter(&self) -> Event<&P, Unpause, N>

Creates a new event filter for the Unpause event.