pub enum TokenMessengerEvents {
DepositForBurn(DepositForBurn),
LocalMinterAdded(LocalMinterAdded),
LocalMinterRemoved(LocalMinterRemoved),
MintAndWithdraw(MintAndWithdraw),
OwnershipTransferStarted(OwnershipTransferStarted),
OwnershipTransferred(OwnershipTransferred),
RemoteTokenMessengerAdded(RemoteTokenMessengerAdded),
RemoteTokenMessengerRemoved(RemoteTokenMessengerRemoved),
RescuerChanged(RescuerChanged),
}Expand description
Container for all the TokenMessenger events.
Variants
DepositForBurn(DepositForBurn)
LocalMinterAdded(LocalMinterAdded)
LocalMinterRemoved(LocalMinterRemoved)
MintAndWithdraw(MintAndWithdraw)
OwnershipTransferStarted(OwnershipTransferStarted)
OwnershipTransferred(OwnershipTransferred)
RemoteTokenMessengerAdded(RemoteTokenMessengerAdded)
RemoteTokenMessengerRemoved(RemoteTokenMessengerRemoved)
RescuerChanged(RescuerChanged)
Implementations
Sourceimpl TokenMessengerEvents
impl TokenMessengerEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl TokenMessengerEvents
impl TokenMessengerEvents
Sourcepub fn deposit_for_burn(
nonce: u64,
burn_token: Address,
amount: U256,
depositor: Address,
mint_recipient: FixedBytes<32>,
destination_domain: u32,
destination_token_messenger: FixedBytes<32>,
destination_caller: FixedBytes<32>,
) -> Self
pub fn deposit_for_burn( nonce: u64, burn_token: Address, amount: U256, depositor: Address, mint_recipient: FixedBytes<32>, destination_domain: u32, destination_token_messenger: FixedBytes<32>, destination_caller: FixedBytes<32>, ) -> Self
Creates a DepositForBurn event.
event DepositForBurn(uint64,address,uint256,address,bytes32,uint32,bytes32,bytes32)Sourcepub fn local_minter_added(local_minter: Address) -> Self
pub fn local_minter_added(local_minter: Address) -> Self
Creates a LocalMinterAdded event.
event LocalMinterAdded(address)Sourcepub fn local_minter_removed(local_minter: Address) -> Self
pub fn local_minter_removed(local_minter: Address) -> Self
Creates a LocalMinterRemoved event.
event LocalMinterRemoved(address)Sourcepub fn mint_and_withdraw(
mint_recipient: Address,
amount: U256,
mint_token: Address,
) -> Self
pub fn mint_and_withdraw( mint_recipient: Address, amount: U256, mint_token: Address, ) -> Self
Creates a MintAndWithdraw event.
event MintAndWithdraw(address,uint256,address)Sourcepub fn ownership_transfer_started(
previous_owner: Address,
new_owner: Address,
) -> Self
pub fn ownership_transfer_started( previous_owner: Address, new_owner: Address, ) -> Self
Creates a OwnershipTransferStarted event.
event OwnershipTransferStarted(address,address)Sourcepub fn ownership_transferred(
previous_owner: Address,
new_owner: Address,
) -> Self
pub fn ownership_transferred( previous_owner: Address, new_owner: Address, ) -> Self
Creates a OwnershipTransferred event.
event OwnershipTransferred(address,address)Sourcepub fn remote_token_messenger_added(
domain: u32,
token_messenger: FixedBytes<32>,
) -> Self
pub fn remote_token_messenger_added( domain: u32, token_messenger: FixedBytes<32>, ) -> Self
Creates a RemoteTokenMessengerAdded event.
event RemoteTokenMessengerAdded(uint32,bytes32)Sourcepub fn remote_token_messenger_removed(
domain: u32,
token_messenger: FixedBytes<32>,
) -> Self
pub fn remote_token_messenger_removed( domain: u32, token_messenger: FixedBytes<32>, ) -> Self
Creates a RemoteTokenMessengerRemoved event.
event RemoteTokenMessengerRemoved(uint32,bytes32)Sourcepub fn rescuer_changed(new_rescuer: Address) -> Self
pub fn rescuer_changed(new_rescuer: Address) -> Self
Creates a RescuerChanged event.
event RescuerChanged(address)Trait Implementations
Sourceimpl Clone for TokenMessengerEvents
impl Clone for TokenMessengerEvents
Sourcefn clone(&self) -> TokenMessengerEvents
fn clone(&self) -> TokenMessengerEvents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl IntoLogData for TokenMessengerEvents
impl IntoLogData for TokenMessengerEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEventInterface for TokenMessengerEvents
impl SolEventInterface for TokenMessengerEvents