pub struct LocalMinterRemoved {
pub localMinter: Address,
}Expand description
Event with signature LocalMinterRemoved(address) and selector 0x2db49fbf671271826a27b02ebc496209c85fffffb4bccc67430d2a0f22b4d1ac.
event LocalMinterRemoved(address localMinter);Fields
localMinter: AddressTrait Implementations
Sourceimpl Clone for LocalMinterRemoved
impl Clone for LocalMinterRemoved
Sourcefn clone(&self) -> LocalMinterRemoved
fn clone(&self) -> LocalMinterRemoved
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<&LocalMinterRemoved> for LogData
impl From<&LocalMinterRemoved> for LogData
Sourcefn from(this: &LocalMinterRemoved) -> LogData
fn from(this: &LocalMinterRemoved) -> LogData
Converts to this type from the input type.
Sourceimpl IntoLogData for LocalMinterRemoved
impl IntoLogData for LocalMinterRemoved
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEvent for LocalMinterRemoved
impl SolEvent for LocalMinterRemoved
Sourceconst SIGNATURE: &'static str = "LocalMinterRemoved(address)"
const SIGNATURE: &'static str = "LocalMinterRemoved(address)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Address,)
type DataTuple<'a> = (Address,)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<LocalMinterRemoved as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<LocalMinterRemoved as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>,)
type TopicList = (FixedBytes<32>,)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type. Read more
Sourcefn check_signature(
topics: &<Self::TopicList as SolType>::RustType,
) -> Result<()>
fn check_signature( topics: &<Self::TopicList as SolType>::RustType, ) -> Result<()>
Check that the event’s signature matches the given topics.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a
LogData.Sourcefn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer, with validation. Read more
Sourcefn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info.
Sourcefn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info, with validation. Read more
Sourcefn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object.
Sourcefn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object with validation.