pub struct TokenMessengerInstance<P, N = Ethereum> { /* private fields */ }Expand description
A TokenMessenger instance.
Contains type-safe methods for interacting with an on-chain instance of the
TokenMessenger contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> TokenMessengerInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> TokenMessengerInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain TokenMessenger contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> TokenMessengerInstance<&P, N>
impl<P: Clone, N> TokenMessengerInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> TokenMessengerInstance<P, N>
pub fn with_cloned_provider(self) -> TokenMessengerInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> TokenMessengerInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> TokenMessengerInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
pub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
Creates a new call builder for the [acceptOwnership] function.
Sourcepub fn addLocalMinter(
&self,
newLocalMinter: Address,
) -> SolCallBuilder<&P, addLocalMinterCall, N>
pub fn addLocalMinter( &self, newLocalMinter: Address, ) -> SolCallBuilder<&P, addLocalMinterCall, N>
Creates a new call builder for the [addLocalMinter] function.
Sourcepub fn addRemoteTokenMessenger(
&self,
domain: u32,
tokenMessenger: FixedBytes<32>,
) -> SolCallBuilder<&P, addRemoteTokenMessengerCall, N>
pub fn addRemoteTokenMessenger( &self, domain: u32, tokenMessenger: FixedBytes<32>, ) -> SolCallBuilder<&P, addRemoteTokenMessengerCall, N>
Creates a new call builder for the [addRemoteTokenMessenger] function.
Sourcepub fn depositForBurn(
&self,
amount: U256,
destinationDomain: u32,
mintRecipient: FixedBytes<32>,
burnToken: Address,
) -> SolCallBuilder<&P, depositForBurnCall, N>
pub fn depositForBurn( &self, amount: U256, destinationDomain: u32, mintRecipient: FixedBytes<32>, burnToken: Address, ) -> SolCallBuilder<&P, depositForBurnCall, N>
Creates a new call builder for the [depositForBurn] function.
Sourcepub fn depositForBurnWithCaller(
&self,
amount: U256,
destinationDomain: u32,
mintRecipient: FixedBytes<32>,
burnToken: Address,
destinationCaller: FixedBytes<32>,
) -> SolCallBuilder<&P, depositForBurnWithCallerCall, N>
pub fn depositForBurnWithCaller( &self, amount: U256, destinationDomain: u32, mintRecipient: FixedBytes<32>, burnToken: Address, destinationCaller: FixedBytes<32>, ) -> SolCallBuilder<&P, depositForBurnWithCallerCall, N>
Creates a new call builder for the [depositForBurnWithCaller] function.
Sourcepub fn handleReceiveMessage(
&self,
remoteDomain: u32,
sender: FixedBytes<32>,
messageBody: Bytes,
) -> SolCallBuilder<&P, handleReceiveMessageCall, N>
pub fn handleReceiveMessage( &self, remoteDomain: u32, sender: FixedBytes<32>, messageBody: Bytes, ) -> SolCallBuilder<&P, handleReceiveMessageCall, N>
Creates a new call builder for the [handleReceiveMessage] function.
Sourcepub fn localMessageTransmitter(
&self,
) -> SolCallBuilder<&P, localMessageTransmitterCall, N>
pub fn localMessageTransmitter( &self, ) -> SolCallBuilder<&P, localMessageTransmitterCall, N>
Creates a new call builder for the [localMessageTransmitter] function.
Sourcepub fn localMinter(&self) -> SolCallBuilder<&P, localMinterCall, N>
pub fn localMinter(&self) -> SolCallBuilder<&P, localMinterCall, N>
Creates a new call builder for the [localMinter] function.
Sourcepub fn messageBodyVersion(
&self,
) -> SolCallBuilder<&P, messageBodyVersionCall, N>
pub fn messageBodyVersion( &self, ) -> SolCallBuilder<&P, messageBodyVersionCall, N>
Creates a new call builder for the [messageBodyVersion] function.
Sourcepub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
pub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
Creates a new call builder for the [owner] function.
Sourcepub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
pub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
Creates a new call builder for the [pendingOwner] function.
Sourcepub fn remoteTokenMessengers(
&self,
_0: u32,
) -> SolCallBuilder<&P, remoteTokenMessengersCall, N>
pub fn remoteTokenMessengers( &self, _0: u32, ) -> SolCallBuilder<&P, remoteTokenMessengersCall, N>
Creates a new call builder for the [remoteTokenMessengers] function.
Sourcepub fn removeLocalMinter(&self) -> SolCallBuilder<&P, removeLocalMinterCall, N>
pub fn removeLocalMinter(&self) -> SolCallBuilder<&P, removeLocalMinterCall, N>
Creates a new call builder for the [removeLocalMinter] function.
Sourcepub fn removeRemoteTokenMessenger(
&self,
domain: u32,
) -> SolCallBuilder<&P, removeRemoteTokenMessengerCall, N>
pub fn removeRemoteTokenMessenger( &self, domain: u32, ) -> SolCallBuilder<&P, removeRemoteTokenMessengerCall, N>
Creates a new call builder for the [removeRemoteTokenMessenger] function.
Sourcepub fn replaceDepositForBurn(
&self,
originalMessage: Bytes,
originalAttestation: Bytes,
newDestinationCaller: FixedBytes<32>,
newMintRecipient: FixedBytes<32>,
) -> SolCallBuilder<&P, replaceDepositForBurnCall, N>
pub fn replaceDepositForBurn( &self, originalMessage: Bytes, originalAttestation: Bytes, newDestinationCaller: FixedBytes<32>, newMintRecipient: FixedBytes<32>, ) -> SolCallBuilder<&P, replaceDepositForBurnCall, N>
Creates a new call builder for the [replaceDepositForBurn] function.
Sourcepub fn rescueERC20(
&self,
tokenContract: Address,
to: Address,
amount: U256,
) -> SolCallBuilder<&P, rescueERC20Call, N>
pub fn rescueERC20( &self, tokenContract: Address, to: Address, amount: U256, ) -> SolCallBuilder<&P, rescueERC20Call, N>
Creates a new call builder for the [rescueERC20] function.
Sourcepub fn rescuer(&self) -> SolCallBuilder<&P, rescuerCall, N>
pub fn rescuer(&self) -> SolCallBuilder<&P, rescuerCall, N>
Creates a new call builder for the [rescuer] function.
Sourcepub fn transferOwnership(
&self,
newOwner: Address,
) -> SolCallBuilder<&P, transferOwnershipCall, N>
pub fn transferOwnership( &self, newOwner: Address, ) -> SolCallBuilder<&P, transferOwnershipCall, N>
Creates a new call builder for the [transferOwnership] function.
Sourcepub fn updateRescuer(
&self,
newRescuer: Address,
) -> SolCallBuilder<&P, updateRescuerCall, N>
pub fn updateRescuer( &self, newRescuer: Address, ) -> SolCallBuilder<&P, updateRescuerCall, N>
Creates a new call builder for the [updateRescuer] function.
Sourceimpl<P: Provider<N>, N: Network> TokenMessengerInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> TokenMessengerInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn DepositForBurn_filter(&self) -> Event<&P, DepositForBurn, N>
pub fn DepositForBurn_filter(&self) -> Event<&P, DepositForBurn, N>
Creates a new event filter for the DepositForBurn event.
Sourcepub fn LocalMinterAdded_filter(&self) -> Event<&P, LocalMinterAdded, N>
pub fn LocalMinterAdded_filter(&self) -> Event<&P, LocalMinterAdded, N>
Creates a new event filter for the LocalMinterAdded event.
Sourcepub fn LocalMinterRemoved_filter(&self) -> Event<&P, LocalMinterRemoved, N>
pub fn LocalMinterRemoved_filter(&self) -> Event<&P, LocalMinterRemoved, N>
Creates a new event filter for the LocalMinterRemoved event.
Sourcepub fn MintAndWithdraw_filter(&self) -> Event<&P, MintAndWithdraw, N>
pub fn MintAndWithdraw_filter(&self) -> Event<&P, MintAndWithdraw, N>
Creates a new event filter for the MintAndWithdraw event.
Sourcepub fn OwnershipTransferStarted_filter(
&self,
) -> Event<&P, OwnershipTransferStarted, N>
pub fn OwnershipTransferStarted_filter( &self, ) -> Event<&P, OwnershipTransferStarted, N>
Creates a new event filter for the OwnershipTransferStarted event.
Sourcepub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
pub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
Creates a new event filter for the OwnershipTransferred event.
Sourcepub fn RemoteTokenMessengerAdded_filter(
&self,
) -> Event<&P, RemoteTokenMessengerAdded, N>
pub fn RemoteTokenMessengerAdded_filter( &self, ) -> Event<&P, RemoteTokenMessengerAdded, N>
Creates a new event filter for the RemoteTokenMessengerAdded event.
Sourcepub fn RemoteTokenMessengerRemoved_filter(
&self,
) -> Event<&P, RemoteTokenMessengerRemoved, N>
pub fn RemoteTokenMessengerRemoved_filter( &self, ) -> Event<&P, RemoteTokenMessengerRemoved, N>
Creates a new event filter for the RemoteTokenMessengerRemoved event.
Sourcepub fn RescuerChanged_filter(&self) -> Event<&P, RescuerChanged, N>
pub fn RescuerChanged_filter(&self) -> Event<&P, RescuerChanged, N>
Creates a new event filter for the RescuerChanged event.