pub struct handleReceiveUnfinalizedMessageCall {
pub remoteDomain: u32,
pub sender: FixedBytes<32>,
pub finalityThresholdExecuted: u32,
pub messageBody: Bytes,
}Expand description
Function with signature handleReceiveUnfinalizedMessage(uint32,bytes32,uint32,bytes) and selector 0x7c92f219.
function handleReceiveUnfinalizedMessage(uint32 remoteDomain, bytes32 sender, uint32 finalityThresholdExecuted, bytes memory messageBody) external returns (bool);Fields
remoteDomain: u32sender: FixedBytes<32>finalityThresholdExecuted: u32messageBody: BytesTrait Implementations
Sourceimpl Clone for handleReceiveUnfinalizedMessageCall
impl Clone for handleReceiveUnfinalizedMessageCall
Sourcefn clone(&self) -> handleReceiveUnfinalizedMessageCall
fn clone(&self) -> handleReceiveUnfinalizedMessageCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for handleReceiveUnfinalizedMessageCall
impl SolCall for handleReceiveUnfinalizedMessageCall
Sourceconst SIGNATURE: &'static str = "handleReceiveUnfinalizedMessage(uint32,bytes32,uint32,bytes)"
const SIGNATURE: &'static str = "handleReceiveUnfinalizedMessage(uint32,bytes32,uint32,bytes)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<32>, FixedBytes<32>, Uint<32>, Bytes)
type Parameters<'a> = (Uint<32>, FixedBytes<32>, Uint<32>, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<handleReceiveUnfinalizedMessageCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<handleReceiveUnfinalizedMessageCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<handleReceiveUnfinalizedMessageCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<handleReceiveUnfinalizedMessageCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.