pub struct InvalidDomainId(pub u32);Expand description
Error returned when attempting to convert an invalid u32 to a DomainId
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for InvalidDomainId
impl Clone for InvalidDomainId
Sourcefn clone(&self) -> InvalidDomainId
fn clone(&self) -> InvalidDomainId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvalidDomainId
impl Debug for InvalidDomainId
Sourceimpl Display for InvalidDomainId
impl Display for InvalidDomainId
Sourceimpl Error for InvalidDomainId
impl Error for InvalidDomainId
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for InvalidDomainId
impl PartialEq for InvalidDomainId
Sourcefn eq(&self, other: &InvalidDomainId) -> bool
fn eq(&self, other: &InvalidDomainId) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for InvalidDomainId
impl Eq for InvalidDomainId
impl StructuralPartialEq for InvalidDomainId