pub struct InvalidFinalityThreshold(pub u32);Expand description
Error returned when attempting to convert an invalid u32 to a FinalityThreshold
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for InvalidFinalityThreshold
impl Clone for InvalidFinalityThreshold
Sourcefn clone(&self) -> InvalidFinalityThreshold
fn clone(&self) -> InvalidFinalityThreshold
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvalidFinalityThreshold
impl Debug for InvalidFinalityThreshold
Sourceimpl Display for InvalidFinalityThreshold
impl Display for InvalidFinalityThreshold
Sourceimpl Error for InvalidFinalityThreshold
impl Error for InvalidFinalityThreshold
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for InvalidFinalityThreshold
impl PartialEq for InvalidFinalityThreshold
Sourcefn eq(&self, other: &InvalidFinalityThreshold) -> bool
fn eq(&self, other: &InvalidFinalityThreshold) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for InvalidFinalityThreshold
impl Eq for InvalidFinalityThreshold
impl StructuralPartialEq for InvalidFinalityThreshold