pub struct MessageTransmitterInstance<P, N = Ethereum> { /* private fields */ }Expand description
A MessageTransmitter instance.
Contains type-safe methods for interacting with an on-chain instance of the
MessageTransmitter contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain MessageTransmitter contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> MessageTransmitterInstance<&P, N>
impl<P: Clone, N> MessageTransmitterInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> MessageTransmitterInstance<P, N>
pub fn with_cloned_provider(self) -> MessageTransmitterInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
pub fn acceptOwnership(&self) -> SolCallBuilder<&P, acceptOwnershipCall, N>
Creates a new call builder for the [acceptOwnership] function.
Sourcepub fn attesterManager(&self) -> SolCallBuilder<&P, attesterManagerCall, N>
pub fn attesterManager(&self) -> SolCallBuilder<&P, attesterManagerCall, N>
Creates a new call builder for the [attesterManager] function.
Sourcepub fn disableAttester(
&self,
attester: Address,
) -> SolCallBuilder<&P, disableAttesterCall, N>
pub fn disableAttester( &self, attester: Address, ) -> SolCallBuilder<&P, disableAttesterCall, N>
Creates a new call builder for the [disableAttester] function.
Sourcepub fn enableAttester(
&self,
newAttester: Address,
) -> SolCallBuilder<&P, enableAttesterCall, N>
pub fn enableAttester( &self, newAttester: Address, ) -> SolCallBuilder<&P, enableAttesterCall, N>
Creates a new call builder for the [enableAttester] function.
Sourcepub fn getEnabledAttester(
&self,
index: U256,
) -> SolCallBuilder<&P, getEnabledAttesterCall, N>
pub fn getEnabledAttester( &self, index: U256, ) -> SolCallBuilder<&P, getEnabledAttesterCall, N>
Creates a new call builder for the [getEnabledAttester] function.
Sourcepub fn getNumEnabledAttesters(
&self,
) -> SolCallBuilder<&P, getNumEnabledAttestersCall, N>
pub fn getNumEnabledAttesters( &self, ) -> SolCallBuilder<&P, getNumEnabledAttestersCall, N>
Creates a new call builder for the [getNumEnabledAttesters] function.
Sourcepub fn isEnabledAttester(
&self,
attester: Address,
) -> SolCallBuilder<&P, isEnabledAttesterCall, N>
pub fn isEnabledAttester( &self, attester: Address, ) -> SolCallBuilder<&P, isEnabledAttesterCall, N>
Creates a new call builder for the [isEnabledAttester] function.
Sourcepub fn localDomain(&self) -> SolCallBuilder<&P, localDomainCall, N>
pub fn localDomain(&self) -> SolCallBuilder<&P, localDomainCall, N>
Creates a new call builder for the [localDomain] function.
Sourcepub fn maxMessageBodySize(
&self,
) -> SolCallBuilder<&P, maxMessageBodySizeCall, N>
pub fn maxMessageBodySize( &self, ) -> SolCallBuilder<&P, maxMessageBodySizeCall, N>
Creates a new call builder for the [maxMessageBodySize] function.
Sourcepub fn nextAvailableNonce(
&self,
) -> SolCallBuilder<&P, nextAvailableNonceCall, N>
pub fn nextAvailableNonce( &self, ) -> SolCallBuilder<&P, nextAvailableNonceCall, N>
Creates a new call builder for the [nextAvailableNonce] function.
Sourcepub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
pub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>
Creates a new call builder for the [owner] function.
Sourcepub fn pause(&self) -> SolCallBuilder<&P, pauseCall, N>
pub fn pause(&self) -> SolCallBuilder<&P, pauseCall, N>
Creates a new call builder for the [pause] function.
Sourcepub fn paused(&self) -> SolCallBuilder<&P, pausedCall, N>
pub fn paused(&self) -> SolCallBuilder<&P, pausedCall, N>
Creates a new call builder for the [paused] function.
Sourcepub fn pauser(&self) -> SolCallBuilder<&P, pauserCall, N>
pub fn pauser(&self) -> SolCallBuilder<&P, pauserCall, N>
Creates a new call builder for the [pauser] function.
Sourcepub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
pub fn pendingOwner(&self) -> SolCallBuilder<&P, pendingOwnerCall, N>
Creates a new call builder for the [pendingOwner] function.
Sourcepub fn receiveMessage(
&self,
message: Bytes,
attestation: Bytes,
) -> SolCallBuilder<&P, receiveMessageCall, N>
pub fn receiveMessage( &self, message: Bytes, attestation: Bytes, ) -> SolCallBuilder<&P, receiveMessageCall, N>
Creates a new call builder for the [receiveMessage] function.
Sourcepub fn replaceMessage(
&self,
originalMessage: Bytes,
originalAttestation: Bytes,
newMessageBody: Bytes,
newDestinationCaller: FixedBytes<32>,
) -> SolCallBuilder<&P, replaceMessageCall, N>
pub fn replaceMessage( &self, originalMessage: Bytes, originalAttestation: Bytes, newMessageBody: Bytes, newDestinationCaller: FixedBytes<32>, ) -> SolCallBuilder<&P, replaceMessageCall, N>
Creates a new call builder for the [replaceMessage] function.
Sourcepub fn rescueERC20(
&self,
tokenContract: Address,
to: Address,
amount: U256,
) -> SolCallBuilder<&P, rescueERC20Call, N>
pub fn rescueERC20( &self, tokenContract: Address, to: Address, amount: U256, ) -> SolCallBuilder<&P, rescueERC20Call, N>
Creates a new call builder for the [rescueERC20] function.
Sourcepub fn rescuer(&self) -> SolCallBuilder<&P, rescuerCall, N>
pub fn rescuer(&self) -> SolCallBuilder<&P, rescuerCall, N>
Creates a new call builder for the [rescuer] function.
Sourcepub fn sendMessage(
&self,
destinationDomain: u32,
recipient: FixedBytes<32>,
messageBody: Bytes,
) -> SolCallBuilder<&P, sendMessageCall, N>
pub fn sendMessage( &self, destinationDomain: u32, recipient: FixedBytes<32>, messageBody: Bytes, ) -> SolCallBuilder<&P, sendMessageCall, N>
Creates a new call builder for the [sendMessage] function.
Sourcepub fn sendMessageWithCaller(
&self,
destinationDomain: u32,
recipient: FixedBytes<32>,
destinationCaller: FixedBytes<32>,
messageBody: Bytes,
) -> SolCallBuilder<&P, sendMessageWithCallerCall, N>
pub fn sendMessageWithCaller( &self, destinationDomain: u32, recipient: FixedBytes<32>, destinationCaller: FixedBytes<32>, messageBody: Bytes, ) -> SolCallBuilder<&P, sendMessageWithCallerCall, N>
Creates a new call builder for the [sendMessageWithCaller] function.
Sourcepub fn setMaxMessageBodySize(
&self,
newMaxMessageBodySize: U256,
) -> SolCallBuilder<&P, setMaxMessageBodySizeCall, N>
pub fn setMaxMessageBodySize( &self, newMaxMessageBodySize: U256, ) -> SolCallBuilder<&P, setMaxMessageBodySizeCall, N>
Creates a new call builder for the [setMaxMessageBodySize] function.
Sourcepub fn setSignatureThreshold(
&self,
newSignatureThreshold: U256,
) -> SolCallBuilder<&P, setSignatureThresholdCall, N>
pub fn setSignatureThreshold( &self, newSignatureThreshold: U256, ) -> SolCallBuilder<&P, setSignatureThresholdCall, N>
Creates a new call builder for the [setSignatureThreshold] function.
Sourcepub fn signatureThreshold(
&self,
) -> SolCallBuilder<&P, signatureThresholdCall, N>
pub fn signatureThreshold( &self, ) -> SolCallBuilder<&P, signatureThresholdCall, N>
Creates a new call builder for the [signatureThreshold] function.
Sourcepub fn transferOwnership(
&self,
newOwner: Address,
) -> SolCallBuilder<&P, transferOwnershipCall, N>
pub fn transferOwnership( &self, newOwner: Address, ) -> SolCallBuilder<&P, transferOwnershipCall, N>
Creates a new call builder for the [transferOwnership] function.
Sourcepub fn unpause(&self) -> SolCallBuilder<&P, unpauseCall, N>
pub fn unpause(&self) -> SolCallBuilder<&P, unpauseCall, N>
Creates a new call builder for the [unpause] function.
Sourcepub fn updateAttesterManager(
&self,
newAttesterManager: Address,
) -> SolCallBuilder<&P, updateAttesterManagerCall, N>
pub fn updateAttesterManager( &self, newAttesterManager: Address, ) -> SolCallBuilder<&P, updateAttesterManagerCall, N>
Creates a new call builder for the [updateAttesterManager] function.
Sourcepub fn updatePauser(
&self,
_newPauser: Address,
) -> SolCallBuilder<&P, updatePauserCall, N>
pub fn updatePauser( &self, _newPauser: Address, ) -> SolCallBuilder<&P, updatePauserCall, N>
Creates a new call builder for the [updatePauser] function.
Sourcepub fn updateRescuer(
&self,
newRescuer: Address,
) -> SolCallBuilder<&P, updateRescuerCall, N>
pub fn updateRescuer( &self, newRescuer: Address, ) -> SolCallBuilder<&P, updateRescuerCall, N>
Creates a new call builder for the [updateRescuer] function.
Sourcepub fn usedNonces(
&self,
_0: FixedBytes<32>,
) -> SolCallBuilder<&P, usedNoncesCall, N>
pub fn usedNonces( &self, _0: FixedBytes<32>, ) -> SolCallBuilder<&P, usedNoncesCall, N>
Creates a new call builder for the [usedNonces] function.
Sourcepub fn version(&self) -> SolCallBuilder<&P, versionCall, N>
pub fn version(&self) -> SolCallBuilder<&P, versionCall, N>
Creates a new call builder for the [version] function.
Sourceimpl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> MessageTransmitterInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn AttesterDisabled_filter(&self) -> Event<&P, AttesterDisabled, N>
pub fn AttesterDisabled_filter(&self) -> Event<&P, AttesterDisabled, N>
Creates a new event filter for the AttesterDisabled event.
Sourcepub fn AttesterEnabled_filter(&self) -> Event<&P, AttesterEnabled, N>
pub fn AttesterEnabled_filter(&self) -> Event<&P, AttesterEnabled, N>
Creates a new event filter for the AttesterEnabled event.
Sourcepub fn AttesterManagerUpdated_filter(
&self,
) -> Event<&P, AttesterManagerUpdated, N>
pub fn AttesterManagerUpdated_filter( &self, ) -> Event<&P, AttesterManagerUpdated, N>
Creates a new event filter for the AttesterManagerUpdated event.
Sourcepub fn MaxMessageBodySizeUpdated_filter(
&self,
) -> Event<&P, MaxMessageBodySizeUpdated, N>
pub fn MaxMessageBodySizeUpdated_filter( &self, ) -> Event<&P, MaxMessageBodySizeUpdated, N>
Creates a new event filter for the MaxMessageBodySizeUpdated event.
Sourcepub fn MessageReceived_filter(&self) -> Event<&P, MessageReceived, N>
pub fn MessageReceived_filter(&self) -> Event<&P, MessageReceived, N>
Creates a new event filter for the MessageReceived event.
Sourcepub fn MessageSent_filter(&self) -> Event<&P, MessageSent, N>
pub fn MessageSent_filter(&self) -> Event<&P, MessageSent, N>
Creates a new event filter for the MessageSent event.
Sourcepub fn OwnershipTransferStarted_filter(
&self,
) -> Event<&P, OwnershipTransferStarted, N>
pub fn OwnershipTransferStarted_filter( &self, ) -> Event<&P, OwnershipTransferStarted, N>
Creates a new event filter for the OwnershipTransferStarted event.
Sourcepub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
pub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
Creates a new event filter for the OwnershipTransferred event.
Sourcepub fn Pause_filter(&self) -> Event<&P, Pause, N>
pub fn Pause_filter(&self) -> Event<&P, Pause, N>
Creates a new event filter for the Pause event.
Sourcepub fn PauserChanged_filter(&self) -> Event<&P, PauserChanged, N>
pub fn PauserChanged_filter(&self) -> Event<&P, PauserChanged, N>
Creates a new event filter for the PauserChanged event.
Sourcepub fn RescuerChanged_filter(&self) -> Event<&P, RescuerChanged, N>
pub fn RescuerChanged_filter(&self) -> Event<&P, RescuerChanged, N>
Creates a new event filter for the RescuerChanged event.
Sourcepub fn SignatureThresholdUpdated_filter(
&self,
) -> Event<&P, SignatureThresholdUpdated, N>
pub fn SignatureThresholdUpdated_filter( &self, ) -> Event<&P, SignatureThresholdUpdated, N>
Creates a new event filter for the SignatureThresholdUpdated event.